from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.iam.v1 import user_account_pb2 as _user_account_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TenantUserAccount(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: TenantUserAccountSpec
    status: TenantUserAccountStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[TenantUserAccountSpec, _Mapping]] = ..., status: _Optional[_Union[TenantUserAccountStatus, _Mapping]] = ...) -> None: ...

class TenantUserAccountWithAttributes(_message.Message):
    __slots__ = ["tenant_user_account", "attributes", "error"]
    TENANT_USER_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    tenant_user_account: TenantUserAccount
    attributes: UserAttributes
    error: Error
    def __init__(self, tenant_user_account: _Optional[_Union[TenantUserAccount, _Mapping]] = ..., attributes: _Optional[_Union[UserAttributes, _Mapping]] = ..., error: _Optional[_Union[Error, _Mapping]] = ...) -> None: ...

class UserAttributes(_message.Message):
    __slots__ = ["sub", "name", "given_name", "family_name", "preferred_username", "picture", "email", "email_verified", "zoneinfo", "locale", "phone_number", "phone_number_verified"]
    SUB_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    GIVEN_NAME_FIELD_NUMBER: _ClassVar[int]
    FAMILY_NAME_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_USERNAME_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EMAIL_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    ZONEINFO_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    sub: str
    name: str
    given_name: str
    family_name: str
    preferred_username: str
    picture: str
    email: str
    email_verified: bool
    zoneinfo: str
    locale: str
    phone_number: str
    phone_number_verified: bool
    def __init__(self, sub: _Optional[str] = ..., name: _Optional[str] = ..., given_name: _Optional[str] = ..., family_name: _Optional[str] = ..., preferred_username: _Optional[str] = ..., picture: _Optional[str] = ..., email: _Optional[str] = ..., email_verified: bool = ..., zoneinfo: _Optional[str] = ..., locale: _Optional[str] = ..., phone_number: _Optional[str] = ..., phone_number_verified: bool = ...) -> None: ...

class Error(_message.Message):
    __slots__ = ["message"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class TenantUserAccountSpec(_message.Message):
    __slots__ = ["visible_attributes"]
    class VisibleAttributes(_message.Message):
        __slots__ = ["attribute"]
        ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
        attribute: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, attribute: _Optional[_Iterable[str]] = ...) -> None: ...
    VISIBLE_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    visible_attributes: TenantUserAccountSpec.VisibleAttributes
    def __init__(self, visible_attributes: _Optional[_Union[TenantUserAccountSpec.VisibleAttributes, _Mapping]] = ...) -> None: ...

class TenantUserAccountStatus(_message.Message):
    __slots__ = ["state", "invitation_id", "federation_id", "user_account_state"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[TenantUserAccountStatus.State]
        ACTIVE: _ClassVar[TenantUserAccountStatus.State]
        INACTIVE: _ClassVar[TenantUserAccountStatus.State]
        BLOCKED: _ClassVar[TenantUserAccountStatus.State]
    STATE_UNSPECIFIED: TenantUserAccountStatus.State
    ACTIVE: TenantUserAccountStatus.State
    INACTIVE: TenantUserAccountStatus.State
    BLOCKED: TenantUserAccountStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    INVITATION_ID_FIELD_NUMBER: _ClassVar[int]
    FEDERATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ACCOUNT_STATE_FIELD_NUMBER: _ClassVar[int]
    state: TenantUserAccountStatus.State
    invitation_id: str
    federation_id: str
    user_account_state: _user_account_pb2.UserAccountStatus.State
    def __init__(self, state: _Optional[_Union[TenantUserAccountStatus.State, str]] = ..., invitation_id: _Optional[str] = ..., federation_id: _Optional[str] = ..., user_account_state: _Optional[_Union[_user_account_pb2.UserAccountStatus.State, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mysterybox/v1/payload_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.mysterybox.v1 import payload_pb2 as nebius_dot_mysterybox_dot_v1_dot_payload__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*nebius/mysterybox/v1/payload_service.proto\x12\x14nebius.mysterybox.v1\x1a\"nebius/mysterybox/v1/payload.proto\x1a\x18nebius/annotations.proto\x1a\x1b\x62uf/validate/validate.proto\"U\n\x11GetPayloadRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId\x12#\n\nversion_id\x18\x02 \x01(\tB\x04\xbaJ\x01\x07R\tversionId\"t\n\x16GetPayloadByKeyRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId\x12#\n\nversion_id\x18\x02 \x01(\tB\x04\xbaJ\x01\x07R\tversionId\x12\x18\n\x03key\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03key\"a\n\rSecretPayload\x12\x1d\n\nversion_id\x18\x01 \x01(\tR\tversionId\x12\x31\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x1d.nebius.mysterybox.v1.PayloadR\x04\x64\x61ta\"f\n\x12SecretPayloadEntry\x12\x1d\n\nversion_id\x18\x01 \x01(\tR\tversionId\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.nebius.mysterybox.v1.PayloadR\x04\x64\x61ta2\xdc\x01\n\x0ePayloadService\x12S\n\x03Get\x12\'.nebius.mysterybox.v1.GetPayloadRequest\x1a#.nebius.mysterybox.v1.SecretPayload\x12\x62\n\x08GetByKey\x12,.nebius.mysterybox.v1.GetPayloadByKeyRequest\x1a(.nebius.mysterybox.v1.SecretPayloadEntry\x1a\x11\xbaJ\x0e\x64pl.mysteryboxBh\n\x1b\x61i.nebius.pub.mysterybox.v1B\x13PayloadServiceProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mysterybox.v1.payload_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mysterybox.v1B\023PayloadServiceProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1'
  _GETPAYLOADREQUEST.fields_by_name['version_id']._options = None
  _GETPAYLOADREQUEST.fields_by_name['version_id']._serialized_options = b'\272J\001\007'
  _GETPAYLOADBYKEYREQUEST.fields_by_name['version_id']._options = None
  _GETPAYLOADBYKEYREQUEST.fields_by_name['version_id']._serialized_options = b'\272J\001\007'
  _GETPAYLOADBYKEYREQUEST.fields_by_name['key']._options = None
  _GETPAYLOADBYKEYREQUEST.fields_by_name['key']._serialized_options = b'\272H\003\310\001\001'
  _PAYLOADSERVICE._options = None
  _PAYLOADSERVICE._serialized_options = b'\272J\016dpl.mysterybox'
  _globals['_GETPAYLOADREQUEST']._serialized_start=159
  _globals['_GETPAYLOADREQUEST']._serialized_end=244
  _globals['_GETPAYLOADBYKEYREQUEST']._serialized_start=246
  _globals['_GETPAYLOADBYKEYREQUEST']._serialized_end=362
  _globals['_SECRETPAYLOAD']._serialized_start=364
  _globals['_SECRETPAYLOAD']._serialized_end=461
  _globals['_SECRETPAYLOADENTRY']._serialized_start=463
  _globals['_SECRETPAYLOADENTRY']._serialized_end=565
  _globals['_PAYLOADSERVICE']._serialized_start=568
  _globals['_PAYLOADSERVICE']._serialized_end=788
# @@protoc_insertion_point(module_scope)



import re
from keyword import iskeyword, issoftkeyword
from logging import getLogger

pep8_const_re = re.compile(r"^_?[A-Z][A-Z0-9_]*$")
pep8_class_re = re.compile(r"^_?[A-Z][a-zA-Z0-9_]*$")
pep8_method_re = re.compile(r"^_?[a-z][a-z0-9_]*$")
pep8_attr_re = re.compile(r"^_?[a-z][a-z0-9_]*$")

logger = getLogger(__name__)


class NameError(Exception):
    pass


def first_non_underscore(s: str) -> str:
    for char in s:
        if char != "_":
            return char
    return ""


def is_reserved_name(s: str) -> bool:
    return iskeyword(s) or issoftkeyword(s)


def _modify_name(
    suggested_name: str,
    container_name: str,
    *,
    lower: bool = True,
    full_proto_name: str = "",
) -> str:
    # get first container name letter
    first_container_letter = first_non_underscore(container_name)
    if first_container_letter == "":
        first_container_letter = "x"
    if lower:
        first_container_letter = first_container_letter.lower()
    else:
        first_container_letter = first_container_letter.upper()

    # if suggested name is reserved or conflicts with getter, prefix it
    if is_reserved_name(suggested_name):
        ret = f"{first_container_letter}_{suggested_name}"
        logger.warning(
            f"Suggested name '{suggested_name}' for {full_proto_name} is reserved in"
            " Python and cannot be "
            f"used. Prefixing with first container letter {first_container_letter}."
            f" Resulting name: '{ret}'."
        )
        return ret

    # Check keywords conflict pattern
    # We have to do it regardless of actual conflict because it has to be always
    # deterministic and the name has to stay the same
    conflict_with_reserved_words = rf"^({first_container_letter}+)_(.*)$"
    match1 = re.match(conflict_with_reserved_words, suggested_name)
    if match1:
        prefix, something = match1.groups()
        if is_reserved_name(something):
            # Add another letter to the sequence
            ret = f"{prefix + first_container_letter}_{something}"
            logger.warning(
                f"Suggested name '{suggested_name}' for {full_proto_name} potentially"
                " conflicts with other"
                f" units renamed from a reserved word '{something}'."
                f" Prefixing with repeated first container letter "
                f"{first_container_letter}. Resulting name: '{ret}'."
            )
            return ret

    # Check magic conflict pattern
    # As in previous check, we have to check for both the original and the potentially
    # modified names, because we don't want conflicts
    conflict_with_magic_methods = rf"^_({first_container_letter}*)_(.*)__$"
    match2 = re.match(conflict_with_magic_methods, suggested_name)
    if match2:
        prefix, something = match2.groups()
        # Add another letter to the sequence
        ret = f"_{prefix + first_container_letter}_{something}__"
        logger.warning(
            f"Suggested name '{suggested_name}' for {full_proto_name} potentially "
            "conflicts with Python magic"
            f" methods '{something}' or units renamed from them."
            f" Prefixing with repeated first container letter {first_container_letter}."
            f" Resulting name: '{ret}'."
        )
        return ret

    # If no pattern matches, return the original string
    return suggested_name


def _class_name(full_name: str, annotated_name: str = "") -> str:
    if annotated_name != "":
        if is_reserved_name(annotated_name):
            raise NameError(
                f"Class name '{annotated_name}' is reserved in Python and cannot be "
                "used."
            )
        if re.match(r"^__.*__$", annotated_name):
            raise NameError(
                f"Class name '{annotated_name}' conflicts with Python magic methods."
            )
        if not pep8_class_re.match(annotated_name):
            raise NameError(
                f"Class name '{annotated_name}' is not a canonical Python class name."
            )
        if annotated_name.startswith("_"):
            raise NameError(
                f"Class name '{annotated_name}' should not start with an underscore."
            )
        return annotated_name
    name_parts = full_name.split(".")
    class_name = name_parts[-1]
    container_name = name_parts[-2] if len(name_parts) > 1 else ""
    return _modify_name(class_name, container_name, full_proto_name=full_name)


# canonical enum names are already pythonic, we have to only check for conflicts
def enum(
    full_enum_name: str, annotated_name: str = "", full_proto_name: str = ""
) -> str:
    return _class_name(full_enum_name, annotated_name=annotated_name)


# canonical message names are already pythonic, we have to only check for conflicts
def message(full_enum_name: str, annotated_name: str = "") -> str:
    return _class_name(full_enum_name, annotated_name=annotated_name)


# canonical one-of names are already pythonic, we have to only check for conflicts
def one_of(
    field_name: str,
    message_name: str,
    annotated_name: str = "",
    full_proto_name: str = "",
) -> str:
    if annotated_name != "":
        if is_reserved_name(annotated_name):
            raise NameError(
                f"OneOf name '{annotated_name}' is reserved in Python and cannot be"
                " used."
            )
        if re.match(r"^__.*__$", annotated_name):
            raise NameError(
                f"OneOf name '{annotated_name}' conflicts with Python magic methods."
            )
        if not pep8_attr_re.match(annotated_name):
            raise NameError(
                f"OneOf name '{annotated_name}' is not a canonical Python attribute"
                " name."
            )
        if annotated_name.startswith("_"):
            raise NameError(
                f"OneOf name '{annotated_name}' should not start with an underscore."
            )
        return annotated_name
    return _modify_name(field_name, message_name, full_proto_name=full_proto_name)


def service(full_service_name: str, annotated_name: str = "") -> str:
    return _class_name(full_service_name, annotated_name)


# canonical field names are already pythonic, we have to only check for conflicts
def field(
    field_name: str,
    message_name: str,
    annotated_name: str = "",
    full_proto_name: str = "",
) -> str:
    if annotated_name != "":
        if is_reserved_name(annotated_name):
            raise NameError(
                f"Field name '{annotated_name}' is reserved in Python and cannot be"
                " used."
            )
        if re.match(r"^__.*__$", annotated_name):
            raise NameError(
                f"Field name '{annotated_name}' conflicts with Python magic methods."
            )
        if not pep8_attr_re.match(annotated_name):
            raise NameError(
                f"Field name '{annotated_name}' is not a canonical Python attribute"
                " name."
            )
        if annotated_name.startswith("_"):
            raise NameError(
                f"Field name '{annotated_name}' should not start with an underscore."
            )
        return annotated_name
    return _modify_name(field_name, message_name, full_proto_name=full_proto_name)


# canonical enum value names are already pythonic, we have to only check for conflicts
def enum_value(
    value_name: str, enum_name: str, annotated_name: str = "", full_proto_name: str = ""
) -> str:
    if annotated_name != "":
        if is_reserved_name(annotated_name):
            raise NameError(
                f"Enum value name '{annotated_name}' is reserved in Python and cannot "
                "be used."
            )
        if re.match(r"^__.*__$", annotated_name):
            raise NameError(
                f"Enum value name '{annotated_name}' conflicts with Python magic "
                "methods."
            )
        if not pep8_const_re.match(annotated_name):
            raise NameError(
                f"Enum value name '{annotated_name}' is not a canonical Python constant"
                " name."
            )
        if annotated_name.startswith("_"):
            raise NameError(
                f"Enum value name '{annotated_name}' should not start with an"
                " underscore."
            )
        return annotated_name
    return _modify_name(
        value_name, enum_name, lower=False, full_proto_name=full_proto_name
    )


def pascal_to_snake_case(name: str) -> str:
    """
    Converts a PascalCase string to snake_case with double underscores as separators
    and respects abbreviations. Also ensures no collisions by appending unique suffixes
    if needed.
    """
    has_underscore = name[0] == "_"
    # Step 1: Separate PascalCase components
    name = re.sub(r"(_+)", r"_\1", name)
    name = re.sub(r"(?<=[A-Z])([A-Z][a-z])", r"_\1", name)
    name = re.sub(r"(?<=_)([a-z])", r"_\1", name)
    name = re.sub(r"(?<=[a-z0-9])([A-Z])", r"_\1", name)

    if not has_underscore and name[0] == "_":
        name = name[1:]
    # Step 3: Convert to lowercase
    return name.lower()


# convert all pascal methods to snake case
def method(
    method_name: str,
    service_name: str,
    annotated_name: str = "",
    full_proto_name: str = "",
) -> str:
    if annotated_name != "":
        if is_reserved_name(annotated_name):
            raise NameError(
                f"Method name '{annotated_name}' is reserved in Python and cannot be"
                " used."
            )
        if re.match(r"^__.*__$", annotated_name):
            raise NameError(
                f"Method name '{annotated_name}' conflicts with Python magic methods."
            )
        if not pep8_method_re.match(annotated_name):
            raise NameError(
                f"Method name '{annotated_name}' is not a canonical Python method name."
            )
        if annotated_name.startswith("_"):
            raise NameError(
                f"Method name '{annotated_name}' should not start with an underscore."
            )
        return annotated_name
    return _modify_name(
        pascal_to_snake_case(method_name), service_name, full_proto_name=full_proto_name
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/common/v1/error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cnebius/common/v1/error.proto\x12\x10nebius.common.v1\"\xa0\t\n\x0cServiceError\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12?\n\x0b\x62\x61\x64_request\x18\x64 \x01(\x0b\x32\x1c.nebius.common.v1.BadRequestH\x00R\nbadRequest\x12R\n\x12\x62\x61\x64_resource_state\x18n \x01(\x0b\x32\".nebius.common.v1.BadResourceStateH\x00R\x10\x62\x61\x64ResourceState\x12R\n\x12resource_not_found\x18o \x01(\x0b\x32\".nebius.common.v1.ResourceNotFoundH\x00R\x10resourceNotFound\x12\x61\n\x17resource_already_exists\x18p \x01(\x0b\x32\'.nebius.common.v1.ResourceAlreadyExistsH\x00R\x15resourceAlreadyExists\x12@\n\x0cout_of_range\x18q \x01(\x0b\x32\x1c.nebius.common.v1.OutOfRangeH\x00R\noutOfRange\x12Q\n\x11permission_denied\x18x \x01(\x0b\x32\".nebius.common.v1.PermissionDeniedH\x00R\x10permissionDenied\x12R\n\x11resource_conflict\x18\x82\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceConflictH\x00R\x10resourceConflict\x12R\n\x11operation_aborted\x18\x83\x01 \x01(\x0b\x32\".nebius.common.v1.OperationAbortedH\x00R\x10operationAborted\x12P\n\x11too_many_requests\x18\x8c\x01 \x01(\x0b\x32!.nebius.common.v1.TooManyRequestsH\x00R\x0ftooManyRequests\x12\x46\n\rquota_failure\x18\x8d\x01 \x01(\x0b\x32\x1e.nebius.common.v1.QuotaFailureH\x00R\x0cquotaFailure\x12Y\n\x14not_enough_resources\x18\x8e\x01 \x01(\x0b\x32$.nebius.common.v1.NotEnoughResourcesH\x00R\x12notEnoughResources\x12I\n\x0einternal_error\x18\xe7\x07 \x01(\x0b\x32\x1f.nebius.common.v1.InternalErrorH\x00R\rinternalError\x12G\n\nretry_type\x18\x1e \x01(\x0e\x32(.nebius.common.v1.ServiceError.RetryTypeR\tretryType\"E\n\tRetryType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x43\x41LL\x10\x01\x12\x10\n\x0cUNIT_OF_WORK\x10\x02\x12\x0b\n\x07NOTHING\x10\x03\x42\t\n\x07\x64\x65tails\"\x91\x01\n\nBadRequest\x12\x46\n\nviolations\x18\x01 \x03(\x0b\x32&.nebius.common.v1.BadRequest.ViolationR\nviolations\x1a;\n\tViolation\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"M\n\x10\x42\x61\x64ResourceState\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"3\n\x10ResourceNotFound\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\"8\n\x15ResourceAlreadyExists\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\"M\n\x10ResourceConflict\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"\x8d\x01\n\x10OperationAborted\x12!\n\x0coperation_id\x18\x01 \x01(\tR\x0boperationId\x12\x35\n\x17\x61\x62orted_by_operation_id\x18\x02 \x01(\tR\x14\x61\x62ortedByOperationId\x12\x1f\n\x0bresource_id\x18\x03 \x01(\tR\nresourceId\"@\n\nOutOfRange\x12\x1c\n\trequested\x18\x01 \x01(\tR\trequested\x12\x14\n\x05limit\x18\x02 \x01(\tR\x05limit\"3\n\x10PermissionDenied\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\"I\n\rInternalError\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x19\n\x08trace_id\x18\x02 \x01(\tR\x07traceId\"/\n\x0fTooManyRequests\x12\x1c\n\tviolation\x18\x01 \x01(\tR\tviolation\"\xc9\x01\n\x0cQuotaFailure\x12H\n\nviolations\x18\x01 \x03(\x0b\x32(.nebius.common.v1.QuotaFailure.ViolationR\nviolations\x1ao\n\tViolation\x12\x14\n\x05quota\x18\x01 \x01(\tR\x05quota\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x14\n\x05limit\x18\x03 \x01(\tR\x05limit\x12\x1c\n\trequested\x18\x04 \x01(\tR\trequested\"\xce\x01\n\x12NotEnoughResources\x12N\n\nviolations\x18\x01 \x03(\x0b\x32..nebius.common.v1.NotEnoughResources.ViolationR\nviolations\x1ah\n\tViolation\x12#\n\rresource_type\x18\x01 \x01(\tR\x0cresourceType\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1c\n\trequested\x18\x03 \x01(\tR\trequestedBW\n\x17\x61i.nebius.pub.common.v1B\nErrorProtoP\x01Z.github.com/nebius/gosdk/proto/nebius/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.common.v1.error_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027ai.nebius.pub.common.v1B\nErrorProtoP\001Z.github.com/nebius/gosdk/proto/nebius/common/v1'
  _globals['_SERVICEERROR']._serialized_start=51
  _globals['_SERVICEERROR']._serialized_end=1235
  _globals['_SERVICEERROR_RETRYTYPE']._serialized_start=1155
  _globals['_SERVICEERROR_RETRYTYPE']._serialized_end=1224
  _globals['_BADREQUEST']._serialized_start=1238
  _globals['_BADREQUEST']._serialized_end=1383
  _globals['_BADREQUEST_VIOLATION']._serialized_start=1324
  _globals['_BADREQUEST_VIOLATION']._serialized_end=1383
  _globals['_BADRESOURCESTATE']._serialized_start=1385
  _globals['_BADRESOURCESTATE']._serialized_end=1462
  _globals['_RESOURCENOTFOUND']._serialized_start=1464
  _globals['_RESOURCENOTFOUND']._serialized_end=1515
  _globals['_RESOURCEALREADYEXISTS']._serialized_start=1517
  _globals['_RESOURCEALREADYEXISTS']._serialized_end=1573
  _globals['_RESOURCECONFLICT']._serialized_start=1575
  _globals['_RESOURCECONFLICT']._serialized_end=1652
  _globals['_OPERATIONABORTED']._serialized_start=1655
  _globals['_OPERATIONABORTED']._serialized_end=1796
  _globals['_OUTOFRANGE']._serialized_start=1798
  _globals['_OUTOFRANGE']._serialized_end=1862
  _globals['_PERMISSIONDENIED']._serialized_start=1864
  _globals['_PERMISSIONDENIED']._serialized_end=1915
  _globals['_INTERNALERROR']._serialized_start=1917
  _globals['_INTERNALERROR']._serialized_end=1990
  _globals['_TOOMANYREQUESTS']._serialized_start=1992
  _globals['_TOOMANYREQUESTS']._serialized_end=2039
  _globals['_QUOTAFAILURE']._serialized_start=2042
  _globals['_QUOTAFAILURE']._serialized_end=2243
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_start=2132
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_end=2243
  _globals['_NOTENOUGHRESOURCES']._serialized_start=2246
  _globals['_NOTENOUGHRESOURCES']._serialized_end=2452
  _globals['_NOTENOUGHRESOURCES_VIOLATION']._serialized_start=2348
  _globals['_NOTENOUGHRESOURCES_VIOLATION']._serialized_end=2452
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.common.v1 import operation_service_pb2 as nebius_dot_common_dot_v1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1 import instance_pb2 as nebius_dot_compute_dot_v1_dot_instance__pb2
from nebius.api.nebius.compute.v1 import operation_service_pb2 as nebius_dot_compute_dot_v1_dot_operation__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/compute/v1/instance_service.proto\x12\x11nebius.compute.v1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a(nebius/common/v1/operation_service.proto\x1a nebius/compute/v1/instance.proto\x1a)nebius/compute/v1/operation_service.proto\"$\n\x12GetInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"o\n\x14ListInstancesRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x8c\x01\n\x15\x43reateInstanceRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32\x1f.nebius.compute.v1.InstanceSpecR\x04spec\"\x8c\x01\n\x15UpdateInstanceRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32\x1f.nebius.compute.v1.InstanceSpecR\x04spec\"\'\n\x15\x44\x65leteInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"r\n\x15ListInstancesResponse\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\x1b.nebius.compute.v1.InstanceR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"&\n\x14StartInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"%\n\x13StopInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id2\x96\x06\n\x0fInstanceService\x12I\n\x03Get\x12%.nebius.compute.v1.GetInstanceRequest\x1a\x1b.nebius.compute.v1.Instance\x12L\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x1b.nebius.compute.v1.Instance\x12Y\n\x04List\x12\'.nebius.compute.v1.ListInstancesRequest\x1a(.nebius.compute.v1.ListInstancesResponse\x12O\n\x06\x43reate\x12(.nebius.compute.v1.CreateInstanceRequest\x1a\x1b.nebius.common.v1.Operation\x12O\n\x06Update\x12(.nebius.compute.v1.UpdateInstanceRequest\x1a\x1b.nebius.common.v1.Operation\x12O\n\x06\x44\x65lete\x12(.nebius.compute.v1.DeleteInstanceRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x05Start\x12\'.nebius.compute.v1.StartInstanceRequest\x1a\x1b.nebius.common.v1.Operation\x12K\n\x04Stop\x12&.nebius.compute.v1.StopInstanceRequest\x1a\x1b.nebius.common.v1.Operation\x12t\n\x16ListOperationsByParent\x12\x30.nebius.compute.v1.ListOperationsByParentRequest\x1a(.nebius.common.v1.ListOperationsResponse\x1a\n\xbaJ\x07\x63omputeBc\n\x18\x61i.nebius.pub.compute.v1B\x14InstanceServiceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.instance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\024InstanceServiceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _INSTANCESERVICE._options = None
  _INSTANCESERVICE._serialized_options = b'\272J\007compute'
  _globals['_GETINSTANCEREQUEST']._serialized_start=275
  _globals['_GETINSTANCEREQUEST']._serialized_end=311
  _globals['_LISTINSTANCESREQUEST']._serialized_start=313
  _globals['_LISTINSTANCESREQUEST']._serialized_end=424
  _globals['_CREATEINSTANCEREQUEST']._serialized_start=427
  _globals['_CREATEINSTANCEREQUEST']._serialized_end=567
  _globals['_UPDATEINSTANCEREQUEST']._serialized_start=570
  _globals['_UPDATEINSTANCEREQUEST']._serialized_end=710
  _globals['_DELETEINSTANCEREQUEST']._serialized_start=712
  _globals['_DELETEINSTANCEREQUEST']._serialized_end=751
  _globals['_LISTINSTANCESRESPONSE']._serialized_start=753
  _globals['_LISTINSTANCESRESPONSE']._serialized_end=867
  _globals['_STARTINSTANCEREQUEST']._serialized_start=869
  _globals['_STARTINSTANCEREQUEST']._serialized_end=907
  _globals['_STOPINSTANCEREQUEST']._serialized_start=909
  _globals['_STOPINSTANCEREQUEST']._serialized_end=946
  _globals['_INSTANCESERVICE']._serialized_start=949
  _globals['_INSTANCESERVICE']._serialized_end=1739
# @@protoc_insertion_point(module_scope)



from logging import getLogger

from .service_account import Reader as BaseReader
from .service_account import ServiceAccount

log = getLogger(__name__)


class Reader(BaseReader):
    def __init__(self, service_account: ServiceAccount) -> None:
        self._sa = service_account

    def read(self) -> ServiceAccount:
        log.debug("static SA read")
        return self._sa



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scope(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: ScopeSpec
    status: ScopeStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[ScopeSpec, _Mapping]] = ..., status: _Optional[_Union[ScopeStatus, _Mapping]] = ...) -> None: ...

class ScopeSpec(_message.Message):
    __slots__ = ["type"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        SCOPE_TYPE_UNSPECIFIED: _ClassVar[ScopeSpec.Type]
        PUBLIC: _ClassVar[ScopeSpec.Type]
        PRIVATE: _ClassVar[ScopeSpec.Type]
    SCOPE_TYPE_UNSPECIFIED: ScopeSpec.Type
    PUBLIC: ScopeSpec.Type
    PRIVATE: ScopeSpec.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    type: ScopeSpec.Type
    def __init__(self, type: _Optional[_Union[ScopeSpec.Type, str]] = ...) -> None: ...

class ScopeStatus(_message.Message):
    __slots__ = ["state"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[ScopeStatus.State]
        CREATING: _ClassVar[ScopeStatus.State]
        READY: _ClassVar[ScopeStatus.State]
        DELETING: _ClassVar[ScopeStatus.State]
    STATE_UNSPECIFIED: ScopeStatus.State
    CREATING: ScopeStatus.State
    READY: ScopeStatus.State
    DELETING: ScopeStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: ScopeStatus.State
    def __init__(self, state: _Optional[_Union[ScopeStatus.State, str]] = ...) -> None: ...



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetByNameRequest(_message.Message):
    __slots__ = ["parent_id", "name"]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    parent_id: str
    name: str
    def __init__(self, parent_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class DeleteRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class StartRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class StopRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListRequest(_message.Message):
    __slots__ = ["parent_id", "page_size", "page_token"]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    parent_id: str
    page_size: int
    page_token: str
    def __init__(self, parent_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class UpdateVersionRequest(_message.Message):
    __slots__ = ["id", "version"]
    ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    id: str
    version: str
    def __init__(self, id: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...



"""Types for representing the request status returned by RPCs.

This module exposes a small set of helpers used by the request logic to
represent final request statuses and to convert to/from gRPC's
``google.rpc.Status`` representation. The lightweight :class:`RequestStatus`
is used where service-specific details are not required. When the SDK is
aware of service-level errors the richer :class:`RequestStatusExtended` from
``service_error`` is used instead.
"""

from dataclasses import dataclass
from enum import Enum

from google.protobuf.any_pb2 import Any as AnyPb
from google.rpc.status_pb2 import Status as StatusPb  # type: ignore
from grpc import StatusCode


class UnfinishedRequestStatus(Enum):
    """Sentinels used to represent a request that hasn't completed yet."""

    INITIALIZED = 1
    """Request has been initialized but not yet sent.
    """
    SENT = 2
    """Request has been sent but not yet completed.
    """


@dataclass
class RequestStatus:
    """A normalized representation of an RPC status.

    :ivar code: gRPC status code
    :ivar message: human readable message (may be ``None``)
    :ivar details: list of ``google.protobuf.Any`` detail messages
    :ivar request_id: request identifier extracted from metadata
    :ivar trace_id: trace identifier extracted from metadata
    """

    code: StatusCode
    message: str | None
    details: list[AnyPb]
    request_id: str
    trace_id: str

    def to_rpc_status(self) -> StatusPb:  # type: ignore[unused-ignore]
        """Convert this object into a :class:`google.rpc.status_pb2.Status`.

        This is primarily used when the SDK needs to interoperate with
        gRPC-based status helpers.
        """
        ret = StatusPb()  # type: ignore[unused-ignore]
        ret.code = self.code
        ret.message = self.message
        ret.details.extend(self.details)  # type: ignore[unused-ignore]
        return ret  # type: ignore[unused-ignore]

    @classmethod
    def from_rpc_status(
        cls,
        status: StatusPb,  # type: ignore[unused-ignore]
        request_id: str,
        trace_id: str,
    ) -> "RequestStatus":
        """Create a :class:`RequestStatus` from a gRPC Status proto.

        :param status: the protobuf status message
        :param request_id: request id extracted separately from metadata
        :param trace_id: trace id extracted separately from metadata
        :returns: a populated :class:`RequestStatus` instance
        """
        return cls(
            code=status.code,  # type: ignore[unused-ignore]
            message=status.message,  # type: ignore[unused-ignore]
            details=[d for d in status.details],  # type: ignore[unused-ignore]
            request_id=request_id,
            trace_id=trace_id,
        )


def request_status_from_rpc_status(status: StatusPb) -> RequestStatus:  # type: ignore[unused-ignore]
    """Convert a protobuf Status to the SDK's :class:`RequestStatus`.

    When service-level error details are available the SDK uses the richer
    :class:`RequestStatusExtended` defined in :mod:`service_error`.
    """
    from .service_error import RequestStatusExtended

    return RequestStatusExtended.from_rpc_status(status, request_id="", trace_id="")  # type: ignore[unused-ignore]


def request_status_to_rpc_status(status: RequestStatus) -> StatusPb:  # type: ignore[unused-ignore]
    """Convert an SDK :class:`RequestStatus` back into a protobuf Status."""
    return status.to_rpc_status()  # type: ignore[unused-ignore]



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResourceState(_message.Message):
    __slots__ = ["previous", "current"]
    PREVIOUS_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    previous: _struct_pb2.Struct
    current: _struct_pb2.Struct
    def __init__(self, previous: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., current: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ServiceError(_message.Message):
    __slots__ = ["service", "code", "bad_request", "bad_resource_state", "resource_not_found", "resource_already_exists", "out_of_range", "permission_denied", "resource_conflict", "operation_aborted", "too_many_requests", "quota_failure", "not_enough_resources", "internal_error", "retry_type"]
    class RetryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNSPECIFIED: _ClassVar[ServiceError.RetryType]
        CALL: _ClassVar[ServiceError.RetryType]
        UNIT_OF_WORK: _ClassVar[ServiceError.RetryType]
        NOTHING: _ClassVar[ServiceError.RetryType]
    UNSPECIFIED: ServiceError.RetryType
    CALL: ServiceError.RetryType
    UNIT_OF_WORK: ServiceError.RetryType
    NOTHING: ServiceError.RetryType
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    BAD_REQUEST_FIELD_NUMBER: _ClassVar[int]
    BAD_RESOURCE_STATE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_NOT_FOUND_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ALREADY_EXISTS_FIELD_NUMBER: _ClassVar[int]
    OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_DENIED_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_CONFLICT_FIELD_NUMBER: _ClassVar[int]
    OPERATION_ABORTED_FIELD_NUMBER: _ClassVar[int]
    TOO_MANY_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    QUOTA_FAILURE_FIELD_NUMBER: _ClassVar[int]
    NOT_ENOUGH_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_ERROR_FIELD_NUMBER: _ClassVar[int]
    RETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    service: str
    code: str
    bad_request: BadRequest
    bad_resource_state: BadResourceState
    resource_not_found: ResourceNotFound
    resource_already_exists: ResourceAlreadyExists
    out_of_range: OutOfRange
    permission_denied: PermissionDenied
    resource_conflict: ResourceConflict
    operation_aborted: OperationAborted
    too_many_requests: TooManyRequests
    quota_failure: QuotaFailure
    not_enough_resources: NotEnoughResources
    internal_error: InternalError
    retry_type: ServiceError.RetryType
    def __init__(self, service: _Optional[str] = ..., code: _Optional[str] = ..., bad_request: _Optional[_Union[BadRequest, _Mapping]] = ..., bad_resource_state: _Optional[_Union[BadResourceState, _Mapping]] = ..., resource_not_found: _Optional[_Union[ResourceNotFound, _Mapping]] = ..., resource_already_exists: _Optional[_Union[ResourceAlreadyExists, _Mapping]] = ..., out_of_range: _Optional[_Union[OutOfRange, _Mapping]] = ..., permission_denied: _Optional[_Union[PermissionDenied, _Mapping]] = ..., resource_conflict: _Optional[_Union[ResourceConflict, _Mapping]] = ..., operation_aborted: _Optional[_Union[OperationAborted, _Mapping]] = ..., too_many_requests: _Optional[_Union[TooManyRequests, _Mapping]] = ..., quota_failure: _Optional[_Union[QuotaFailure, _Mapping]] = ..., not_enough_resources: _Optional[_Union[NotEnoughResources, _Mapping]] = ..., internal_error: _Optional[_Union[InternalError, _Mapping]] = ..., retry_type: _Optional[_Union[ServiceError.RetryType, str]] = ...) -> None: ...

class BadRequest(_message.Message):
    __slots__ = ["violations"]
    class Violation(_message.Message):
        __slots__ = ["field", "message"]
        FIELD_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        field: str
        message: str
        def __init__(self, field: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...
    VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    violations: _containers.RepeatedCompositeFieldContainer[BadRequest.Violation]
    def __init__(self, violations: _Optional[_Iterable[_Union[BadRequest.Violation, _Mapping]]] = ...) -> None: ...

class BadResourceState(_message.Message):
    __slots__ = ["resource_id", "message"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    message: str
    def __init__(self, resource_id: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...

class ResourceNotFound(_message.Message):
    __slots__ = ["resource_id"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    def __init__(self, resource_id: _Optional[str] = ...) -> None: ...

class ResourceAlreadyExists(_message.Message):
    __slots__ = ["resource_id"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    def __init__(self, resource_id: _Optional[str] = ...) -> None: ...

class ResourceConflict(_message.Message):
    __slots__ = ["resource_id", "message"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    message: str
    def __init__(self, resource_id: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...

class OperationAborted(_message.Message):
    __slots__ = ["operation_id", "aborted_by_operation_id", "resource_id"]
    OPERATION_ID_FIELD_NUMBER: _ClassVar[int]
    ABORTED_BY_OPERATION_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    operation_id: str
    aborted_by_operation_id: str
    resource_id: str
    def __init__(self, operation_id: _Optional[str] = ..., aborted_by_operation_id: _Optional[str] = ..., resource_id: _Optional[str] = ...) -> None: ...

class OutOfRange(_message.Message):
    __slots__ = ["requested", "limit"]
    REQUESTED_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    requested: str
    limit: str
    def __init__(self, requested: _Optional[str] = ..., limit: _Optional[str] = ...) -> None: ...

class PermissionDenied(_message.Message):
    __slots__ = ["resource_id"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    def __init__(self, resource_id: _Optional[str] = ...) -> None: ...

class InternalError(_message.Message):
    __slots__ = ["request_id", "trace_id"]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    TRACE_ID_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    trace_id: str
    def __init__(self, request_id: _Optional[str] = ..., trace_id: _Optional[str] = ...) -> None: ...

class TooManyRequests(_message.Message):
    __slots__ = ["violation"]
    VIOLATION_FIELD_NUMBER: _ClassVar[int]
    violation: str
    def __init__(self, violation: _Optional[str] = ...) -> None: ...

class QuotaFailure(_message.Message):
    __slots__ = ["violations"]
    class Violation(_message.Message):
        __slots__ = ["quota", "message", "limit", "requested"]
        QUOTA_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        LIMIT_FIELD_NUMBER: _ClassVar[int]
        REQUESTED_FIELD_NUMBER: _ClassVar[int]
        quota: str
        message: str
        limit: str
        requested: str
        def __init__(self, quota: _Optional[str] = ..., message: _Optional[str] = ..., limit: _Optional[str] = ..., requested: _Optional[str] = ...) -> None: ...
    VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    violations: _containers.RepeatedCompositeFieldContainer[QuotaFailure.Violation]
    def __init__(self, violations: _Optional[_Iterable[_Union[QuotaFailure.Violation, _Mapping]]] = ...) -> None: ...

class NotEnoughResources(_message.Message):
    __slots__ = ["violations"]
    class Violation(_message.Message):
        __slots__ = ["resource_type", "message", "requested"]
        RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        REQUESTED_FIELD_NUMBER: _ClassVar[int]
        resource_type: str
        message: str
        requested: str
        def __init__(self, resource_type: _Optional[str] = ..., message: _Optional[str] = ..., requested: _Optional[str] = ...) -> None: ...
    VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    violations: _containers.RepeatedCompositeFieldContainer[NotEnoughResources.Violation]
    def __init__(self, violations: _Optional[_Iterable[_Union[NotEnoughResources.Violation, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1alpha1/instance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.vpc.v1alpha1 import network_interface_pb2 as nebius_dot_vpc_dot_v1alpha1_dot_network__interface__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/compute/v1alpha1/instance.proto\x12\x17nebius.compute.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\x1a+nebius/vpc/v1alpha1/network_interface.proto\"\xc6\x01\n\x08Instance\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32%.nebius.compute.v1alpha1.InstanceSpecR\x04spec\x12?\n\x06status\x18\x03 \x01(\x0b\x32\'.nebius.compute.v1alpha1.InstanceStatusR\x06status\"\x83\x06\n\x0cInstanceSpec\x12\x32\n\x12service_account_id\x18\x01 \x01(\tB\x04\xbaJ\x01\x02R\x10serviceAccountId\x12P\n\tresources\x18\x02 \x01(\x0b\x32&.nebius.compute.v1alpha1.ResourcesSpecB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tresources\x12V\n\x0bgpu_cluster\x18\x03 \x01(\x0b\x32/.nebius.compute.v1alpha1.InstanceGpuClusterSpecB\x04\xbaJ\x01\x02R\ngpuCluster\x12\x64\n\x12network_interfaces\x18\x04 \x03(\x0b\x32).nebius.vpc.v1alpha1.NetworkInterfaceSpecB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x11networkInterfaces\x12L\n\tboot_disk\x18\x05 \x01(\x0b\x32).nebius.compute.v1alpha1.AttachedDiskSpecB\x04\xbaJ\x01\x02R\x08\x62ootDisk\x12R\n\x0fsecondary_disks\x18\x06 \x03(\x0b\x32).nebius.compute.v1alpha1.AttachedDiskSpecR\x0esecondaryDisks\x12W\n\x0b\x66ilesystems\x18\x07 \x03(\x0b\x32/.nebius.compute.v1alpha1.AttachedFilesystemSpecB\x04\xbaJ\x01\x02R\x0b\x66ilesystems\x12\x34\n\x14\x63loud_init_user_data\x18\x08 \x01(\tB\x03\xc0J\x01R\x11\x63loudInitUserData\x12\x18\n\x07stopped\x18\r \x01(\x08R\x07stopped\x12^\n\x0frecovery_policy\x18\x0f \x01(\x0e\x32/.nebius.compute.v1alpha1.InstanceRecoveryPolicyB\x04\xbaJ\x01\x02R\x0erecoveryPolicyJ\x04\x08\x0b\x10\x0c\"\\\n\rResourcesSpec\x12\"\n\x08platform\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08platform\x12\x18\n\x06preset\x18\x02 \x01(\tH\x00R\x06presetB\r\n\x04size\x12\x05\xbaH\x02\x08\x01\"(\n\x16InstanceGpuClusterSpec\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xb6\x02\n\x10\x41ttachedDiskSpec\x12]\n\x0b\x61ttach_mode\x18\x01 \x01(\x0e\x32\x34.nebius.compute.v1alpha1.AttachedDiskSpec.AttachModeB\x06\xbaH\x03\xc8\x01\x01R\nattachMode\x12L\n\rexisting_disk\x18\x02 \x01(\x0b\x32%.nebius.compute.v1alpha1.ExistingDiskH\x00R\x0c\x65xistingDisk\x12(\n\x0b\x64\x65vice_name\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x18\x14R\ndeviceName\"<\n\nAttachMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x42\r\n\x04type\x12\x05\xbaH\x02\x08\x01\"&\n\x0c\x45xistingDisk\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\",\n\x12\x45xistingFilesystem\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xd3\x02\n\x16\x41ttachedFilesystemSpec\x12\x63\n\x0b\x61ttach_mode\x18\x01 \x01(\x0e\x32:.nebius.compute.v1alpha1.AttachedFilesystemSpec.AttachModeB\x06\xbaH\x03\xc8\x01\x01R\nattachMode\x12\'\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\ndeviceName\x12^\n\x13\x65xisting_filesystem\x18\x03 \x01(\x0b\x32+.nebius.compute.v1alpha1.ExistingFilesystemH\x00R\x12\x65xistingFilesystem\"<\n\nAttachMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x42\r\n\x04type\x12\x05\xbaH\x02\x08\x01\"\xe9\x02\n\x0eInstanceStatus\x12K\n\x05state\x18\x01 \x01(\x0e\x32\x35.nebius.compute.v1alpha1.InstanceStatus.InstanceStateR\x05state\x12Z\n\x12network_interfaces\x18\x02 \x03(\x0b\x32+.nebius.vpc.v1alpha1.NetworkInterfaceStatusR\x11networkInterfaces\x12 \n\x0breconciling\x18\x05 \x01(\x08R\x0breconciling\"\x8b\x01\n\rInstanceState\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08UPDATING\x10\x02\x12\x0c\n\x08STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\x07\x12\t\n\x05\x45RROR\x10\x08*/\n\x16InstanceRecoveryPolicy\x12\x0b\n\x07RECOVER\x10\x00\x12\x08\n\x04\x46\x41IL\x10\x01\x42k\n\x1e\x61i.nebius.pub.compute.v1alpha1B\rInstanceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\xb8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1alpha1.instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.compute.v1alpha1B\rInstanceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\270\001\001'
  _INSTANCESPEC.fields_by_name['service_account_id']._options = None
  _INSTANCESPEC.fields_by_name['service_account_id']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['resources']._options = None
  _INSTANCESPEC.fields_by_name['resources']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _INSTANCESPEC.fields_by_name['gpu_cluster']._options = None
  _INSTANCESPEC.fields_by_name['gpu_cluster']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['network_interfaces']._options = None
  _INSTANCESPEC.fields_by_name['network_interfaces']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _INSTANCESPEC.fields_by_name['boot_disk']._options = None
  _INSTANCESPEC.fields_by_name['boot_disk']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['filesystems']._options = None
  _INSTANCESPEC.fields_by_name['filesystems']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['cloud_init_user_data']._options = None
  _INSTANCESPEC.fields_by_name['cloud_init_user_data']._serialized_options = b'\300J\001'
  _INSTANCESPEC.fields_by_name['recovery_policy']._options = None
  _INSTANCESPEC.fields_by_name['recovery_policy']._serialized_options = b'\272J\001\002'
  _RESOURCESSPEC.oneofs_by_name['size']._options = None
  _RESOURCESSPEC.oneofs_by_name['size']._serialized_options = b'\272H\002\010\001'
  _RESOURCESSPEC.fields_by_name['platform']._options = None
  _RESOURCESSPEC.fields_by_name['platform']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDDISKSPEC.oneofs_by_name['type']._options = None
  _ATTACHEDDISKSPEC.oneofs_by_name['type']._serialized_options = b'\272H\002\010\001'
  _ATTACHEDDISKSPEC.fields_by_name['attach_mode']._options = None
  _ATTACHEDDISKSPEC.fields_by_name['attach_mode']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDDISKSPEC.fields_by_name['device_name']._options = None
  _ATTACHEDDISKSPEC.fields_by_name['device_name']._serialized_options = b'\272H\004r\002\030\024'
  _EXISTINGDISK.fields_by_name['id']._options = None
  _EXISTINGDISK.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _EXISTINGFILESYSTEM.fields_by_name['id']._options = None
  _EXISTINGFILESYSTEM.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDFILESYSTEMSPEC.oneofs_by_name['type']._options = None
  _ATTACHEDFILESYSTEMSPEC.oneofs_by_name['type']._serialized_options = b'\272H\002\010\001'
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['attach_mode']._options = None
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['attach_mode']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._options = None
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_INSTANCERECOVERYPOLICY']._serialized_start=2416
  _globals['_INSTANCERECOVERYPOLICY']._serialized_end=2463
  _globals['_INSTANCE']._serialized_start=201
  _globals['_INSTANCE']._serialized_end=399
  _globals['_INSTANCESPEC']._serialized_start=402
  _globals['_INSTANCESPEC']._serialized_end=1173
  _globals['_RESOURCESSPEC']._serialized_start=1175
  _globals['_RESOURCESSPEC']._serialized_end=1267
  _globals['_INSTANCEGPUCLUSTERSPEC']._serialized_start=1269
  _globals['_INSTANCEGPUCLUSTERSPEC']._serialized_end=1309
  _globals['_ATTACHEDDISKSPEC']._serialized_start=1312
  _globals['_ATTACHEDDISKSPEC']._serialized_end=1622
  _globals['_ATTACHEDDISKSPEC_ATTACHMODE']._serialized_start=1547
  _globals['_ATTACHEDDISKSPEC_ATTACHMODE']._serialized_end=1607
  _globals['_EXISTINGDISK']._serialized_start=1624
  _globals['_EXISTINGDISK']._serialized_end=1662
  _globals['_EXISTINGFILESYSTEM']._serialized_start=1664
  _globals['_EXISTINGFILESYSTEM']._serialized_end=1708
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_start=1711
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_end=2050
  _globals['_ATTACHEDFILESYSTEMSPEC_ATTACHMODE']._serialized_start=1547
  _globals['_ATTACHEDFILESYSTEMSPEC_ATTACHMODE']._serialized_end=1607
  _globals['_INSTANCESTATUS']._serialized_start=2053
  _globals['_INSTANCESTATUS']._serialized_end=2414
  _globals['_INSTANCESTATUS_INSTANCESTATE']._serialized_start=2275
  _globals['_INSTANCESTATUS_INSTANCESTATE']._serialized_end=2414
# @@protoc_insertion_point(module_scope)



"""Authorization options for requests."""

OPTION_TYPE = "type"
"""The type of the authorization in process.

Possible values are defined in :class:`Types`.

Currently, the only supported types are "default" and "disable".
The default type authorizes requests using the configured
authorization provider, if any. The disable type disables
authorization for the request completely (for instance, to perform requests for the
authorization itself).
"""


class Types:
    """The types of the authorization in process."""

    DEFAULT = "default"
    """The default type of authorization. Not used anywhere, appears here for clarity.
    """
    DISABLE = "disable"
    """Disable authorization for the request completely.

    Used to perform requests for the authorization itself, or to send requests without
    any authorization.
    """



# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.common.error.v1alpha1``"""

import builtins as builtins
import collections.abc as abc
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import nebius.api.nebius.common.error.v1alpha1.common_errors_pb2 as common_errors_pb2
import nebius.api.nebius.common.error.v1alpha1.error_pb2 as error_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.pb_enum as pb_enum
import nebius.base.protos.unset as unset
import typing as typing
#@ local imports here @#

# file: nebius/common/error/v1alpha1/common_errors.proto
class BadRequest(pb_classes.Message):
    """
    The request is invalid.
    """
    
    __PB2_CLASS__ = common_errors_pb2.BadRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.BadRequest",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class Violation(pb_classes.Message):
        __PB2_CLASS__ = common_errors_pb2.BadRequest.Violation
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.BadRequest.Violation",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
        __mask_functions__ = {
        }
        
        def __init__(
            self,
            initial_message: message_1.Message|None = None,
            *,
            field: "builtins.str|None|unset.UnsetType" = unset.Unset,
            message: "builtins.str|None|unset.UnsetType" = unset.Unset,
        ) -> None:
            super().__init__(initial_message)
            if not isinstance(field, unset.UnsetType):
                self.field = field
            if not isinstance(message, unset.UnsetType):
                self.message = message
        
        def __dir__(self) ->abc.Iterable[builtins.str]:
            return [
                "field",
                "message",
            ]
        
        @builtins.property
        def field(self) -> "builtins.str":
            """
            What field value is invalid.
            """
            
            return super()._get_field("field", explicit_presence=False,
            )
        @field.setter
        def field(self, value: "builtins.str|None") -> None:
            return super()._set_field("field",value,explicit_presence=False,
            )
        
        @builtins.property
        def message(self) -> "builtins.str":
            """
            Description why the value is invalid, in English.
            """
            
            return super()._get_field("message", explicit_presence=False,
            )
        @message.setter
        def message(self, value: "builtins.str|None") -> None:
            return super()._set_field("message",value,explicit_presence=False,
            )
        
        __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
            "field":"field",
            "message":"message",
        }
        
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        violations: "abc.Iterable[BadRequest.Violation]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(violations, unset.UnsetType):
            self.violations = violations
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "violations",
            "Violation",
        ]
    
    @builtins.property
    def violations(self) -> "abc.MutableSequence[BadRequest.Violation]":
        """
        Describes all violations.
        """
        
        return super()._get_field("violations", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(BadRequest.Violation,None,None),
        )
    @violations.setter
    def violations(self, value: "abc.Iterable[BadRequest.Violation]|None") -> None:
        return super()._set_field("violations",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "violations":"violations",
        "Violation":"Violation",
    }
    
class BadResourceState(pb_classes.Message):
    """
    The resource we are trying to use, create, change or delete is in a bad state and cannot be used.
    """
    
    __PB2_CLASS__ = common_errors_pb2.BadResourceState
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.BadResourceState",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        message: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_id, unset.UnsetType):
            self.resource_id = resource_id
        if not isinstance(message, unset.UnsetType):
            self.message = message
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_id",
            "message",
        ]
    
    @builtins.property
    def resource_id(self) -> "builtins.str":
        """
        ID of the resource which is bad.
        """
        
        return super()._get_field("resource_id", explicit_presence=False,
        )
    @resource_id.setter
    def resource_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("resource_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def message(self) -> "builtins.str":
        """
        The reason why this state is bad and cannot be used.
        """
        
        return super()._get_field("message", explicit_presence=False,
        )
    @message.setter
    def message(self, value: "builtins.str|None") -> None:
        return super()._set_field("message",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_id":"resource_id",
        "message":"message",
    }
    
class ResourceNotFound(pb_classes.Message):
    """
    Resource we are trying to interact with does not exist.
    """
    
    __PB2_CLASS__ = common_errors_pb2.ResourceNotFound
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.ResourceNotFound",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_id, unset.UnsetType):
            self.resource_id = resource_id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_id",
        ]
    
    @builtins.property
    def resource_id(self) -> "builtins.str":
        """
        ID of the requested resource.
        """
        
        return super()._get_field("resource_id", explicit_presence=False,
        )
    @resource_id.setter
    def resource_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("resource_id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_id":"resource_id",
    }
    
class ResourceAlreadyExists(pb_classes.Message):
    """
    Resource we are trying to create already exists.
    """
    
    __PB2_CLASS__ = common_errors_pb2.ResourceAlreadyExists
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.ResourceAlreadyExists",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_id, unset.UnsetType):
            self.resource_id = resource_id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_id",
        ]
    
    @builtins.property
    def resource_id(self) -> "builtins.str":
        """
        ID of the existing resource.
        """
        
        return super()._get_field("resource_id", explicit_presence=False,
        )
    @resource_id.setter
    def resource_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("resource_id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_id":"resource_id",
    }
    
class ResourceConflict(pb_classes.Message):
    """
    There is a difference between the actual resource state and the expected one.
    """
    
    __PB2_CLASS__ = common_errors_pb2.ResourceConflict
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.ResourceConflict",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        message: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_id, unset.UnsetType):
            self.resource_id = resource_id
        if not isinstance(message, unset.UnsetType):
            self.message = message
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_id",
            "message",
        ]
    
    @builtins.property
    def resource_id(self) -> "builtins.str":
        """
        ID of conflicting resource.
        """
        
        return super()._get_field("resource_id", explicit_presence=False,
        )
    @resource_id.setter
    def resource_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("resource_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def message(self) -> "builtins.str":
        """
        Detailed info about conflict.
        """
        
        return super()._get_field("message", explicit_presence=False,
        )
    @message.setter
    def message(self, value: "builtins.str|None") -> None:
        return super()._set_field("message",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_id":"resource_id",
        "message":"message",
    }
    
class OperationAborted(pb_classes.Message):
    """
    Operation on the resource has been aborted by a subsequent operation.
    """
    
    __PB2_CLASS__ = common_errors_pb2.OperationAborted
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.OperationAborted",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        operation_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        aborted_by_operation_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        resource_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(operation_id, unset.UnsetType):
            self.operation_id = operation_id
        if not isinstance(aborted_by_operation_id, unset.UnsetType):
            self.aborted_by_operation_id = aborted_by_operation_id
        if not isinstance(resource_id, unset.UnsetType):
            self.resource_id = resource_id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "operation_id",
            "aborted_by_operation_id",
            "resource_id",
        ]
    
    @builtins.property
    def operation_id(self) -> "builtins.str":
        """
        ID of the aborted operation
        """
        
        return super()._get_field("operation_id", explicit_presence=False,
        )
    @operation_id.setter
    def operation_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("operation_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def aborted_by_operation_id(self) -> "builtins.str":
        """
        ID of the subsequent operation
        """
        
        return super()._get_field("aborted_by_operation_id", explicit_presence=False,
        )
    @aborted_by_operation_id.setter
    def aborted_by_operation_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("aborted_by_operation_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def resource_id(self) -> "builtins.str":
        """
        Resource ID corresponding to both of the operations
        """
        
        return super()._get_field("resource_id", explicit_presence=False,
        )
    @resource_id.setter
    def resource_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("resource_id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "operation_id":"operation_id",
        "aborted_by_operation_id":"aborted_by_operation_id",
        "resource_id":"resource_id",
    }
    
class OutOfRange(pb_classes.Message):
    """
    Indicates that element with requested parameters is exceeding the particular range.
    """
    
    __PB2_CLASS__ = common_errors_pb2.OutOfRange
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.OutOfRange",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        requested: "builtins.str|None|unset.UnsetType" = unset.Unset,
        limit: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(requested, unset.UnsetType):
            self.requested = requested
        if not isinstance(limit, unset.UnsetType):
            self.limit = limit
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "requested",
            "limit",
        ]
    
    @builtins.property
    def requested(self) -> "builtins.str":
        """
        Requested value.
        """
        
        return super()._get_field("requested", explicit_presence=False,
        )
    @requested.setter
    def requested(self, value: "builtins.str|None") -> None:
        return super()._set_field("requested",value,explicit_presence=False,
        )
    
    @builtins.property
    def limit(self) -> "builtins.str":
        """
        Available limit.
        """
        
        return super()._get_field("limit", explicit_presence=False,
        )
    @limit.setter
    def limit(self, value: "builtins.str|None") -> None:
        return super()._set_field("limit",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "requested":"requested",
        "limit":"limit",
    }
    
class PermissionDenied(pb_classes.Message):
    """
    Indicates that the action cannot be performed because there are insufficient access rights to a resource.
    """
    
    __PB2_CLASS__ = common_errors_pb2.PermissionDenied
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.PermissionDenied",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_id, unset.UnsetType):
            self.resource_id = resource_id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_id",
        ]
    
    @builtins.property
    def resource_id(self) -> "builtins.str":
        """
        ID of the resource that cannot be accessed.
        """
        
        return super()._get_field("resource_id", explicit_presence=False,
        )
    @resource_id.setter
    def resource_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("resource_id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_id":"resource_id",
    }
    
class InternalError(pb_classes.Message):
    """
    Generic internal error.
    """
    
    __PB2_CLASS__ = common_errors_pb2.InternalError
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.InternalError",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        request_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        trace_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(request_id, unset.UnsetType):
            self.request_id = request_id
        if not isinstance(trace_id, unset.UnsetType):
            self.trace_id = trace_id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "request_id",
            "trace_id",
        ]
    
    @builtins.property
    def request_id(self) -> "builtins.str":
        """
        Error request ID.
        """
        
        return super()._get_field("request_id", explicit_presence=False,
        )
    @request_id.setter
    def request_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("request_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def trace_id(self) -> "builtins.str":
        """
        Trace ID for the failing request.
        """
        
        return super()._get_field("trace_id", explicit_presence=False,
        )
    @trace_id.setter
    def trace_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("trace_id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "request_id":"request_id",
        "trace_id":"trace_id",
    }
    
class TooManyRequests(pb_classes.Message):
    """
    You initiated too many requests to the service at once. Enhance your calm.
    """
    
    __PB2_CLASS__ = common_errors_pb2.TooManyRequests
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.TooManyRequests",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        violation: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(violation, unset.UnsetType):
            self.violation = violation
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "violation",
        ]
    
    @builtins.property
    def violation(self) -> "builtins.str":
        """
        What request limit is exceeded (service-dependent).
        """
        
        return super()._get_field("violation", explicit_presence=False,
        )
    @violation.setter
    def violation(self, value: "builtins.str|None") -> None:
        return super()._set_field("violation",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "violation":"violation",
    }
    
class QuotaFailure(pb_classes.Message):
    """
    Indicates a failure due to exceeding specified limits or allocations in a system or service
    """
    
    __PB2_CLASS__ = common_errors_pb2.QuotaFailure
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.QuotaFailure",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class Violation(pb_classes.Message):
        __PB2_CLASS__ = common_errors_pb2.QuotaFailure.Violation
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.QuotaFailure.Violation",common_errors_pb2.DESCRIPTOR,descriptor_1.Descriptor)
        __mask_functions__ = {
        }
        
        def __init__(
            self,
            initial_message: message_1.Message|None = None,
            *,
            quota: "builtins.str|None|unset.UnsetType" = unset.Unset,
            message: "builtins.str|None|unset.UnsetType" = unset.Unset,
            limit: "builtins.str|None|unset.UnsetType" = unset.Unset,
            requested: "builtins.str|None|unset.UnsetType" = unset.Unset,
        ) -> None:
            super().__init__(initial_message)
            if not isinstance(quota, unset.UnsetType):
                self.quota = quota
            if not isinstance(message, unset.UnsetType):
                self.message = message
            if not isinstance(limit, unset.UnsetType):
                self.limit = limit
            if not isinstance(requested, unset.UnsetType):
                self.requested = requested
        
        def __dir__(self) ->abc.Iterable[builtins.str]:
            return [
                "quota",
                "message",
                "limit",
                "requested",
            ]
        
        @builtins.property
        def quota(self) -> "builtins.str":
            """
            Which quota check failed.
            """
            
            return super()._get_field("quota", explicit_presence=False,
            )
        @quota.setter
        def quota(self, value: "builtins.str|None") -> None:
            return super()._set_field("quota",value,explicit_presence=False,
            )
        
        @builtins.property
        def message(self) -> "builtins.str":
            """
            A description of how the quota check failed.
            """
            
            return super()._get_field("message", explicit_presence=False,
            )
        @message.setter
        def message(self, value: "builtins.str|None") -> None:
            return super()._set_field("message",value,explicit_presence=False,
            )
        
        @builtins.property
        def limit(self) -> "builtins.str":
            """
            Maximum permissible value.
            """
            
            return super()._get_field("limit", explicit_presence=False,
            )
        @limit.setter
        def limit(self, value: "builtins.str|None") -> None:
            return super()._set_field("limit",value,explicit_presence=False,
            )
        
        @builtins.property
        def requested(self) -> "builtins.str":
            """
            Requested value.
            """
            
            return super()._get_field("requested", explicit_presence=False,
            )
        @requested.setter
        def requested(self, value: "builtins.str|None") -> None:
            return super()._set_field("requested",value,explicit_presence=False,
            )
        
        __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
            "quota":"quota",
            "message":"message",
            "limit":"limit",
            "requested":"requested",
        }
        
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        violations: "abc.Iterable[QuotaFailure.Violation]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(violations, unset.UnsetType):
            self.violations = violations
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "violations",
            "Violation",
        ]
    
    @builtins.property
    def violations(self) -> "abc.MutableSequence[QuotaFailure.Violation]":
        """
        Describes all quota violations
        """
        
        return super()._get_field("violations", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(QuotaFailure.Violation,None,None),
        )
    @violations.setter
    def violations(self, value: "abc.Iterable[QuotaFailure.Violation]|None") -> None:
        return super()._set_field("violations",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "violations":"violations",
        "Violation":"Violation",
    }
    
# file: nebius/common/error/v1alpha1/error.proto
class ServiceError(pb_classes.Message):
    __PB2_CLASS__ = error_pb2.ServiceError
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.common.error.v1alpha1.ServiceError",error_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class RetryType(pb_enum.Enum):
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.common.error.v1alpha1.ServiceError.RetryType",error_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        UNSPECIFIED = 0
        CALL = 1
        """
        Just retry the failed call.
        """
        
        UNIT_OF_WORK = 2
        """
        Retry whole logic before call and make a new one.
        """
        
        NOTHING = 3
        """
        Do not retry, this is a fatal error.
        """
        
    
    class __OneOfClass_details__(pb_classes.OneOf):
        name: builtins.str= "details"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__()
            self._message: "ServiceError" = msg
    
    class __OneOfClass_details_bad_request__(__OneOfClass_details__):
        field: typing.Literal["bad_request"] = "bad_request"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "BadRequest":
            return self._message.bad_request
    
    class __OneOfClass_details_bad_resource_state__(__OneOfClass_details__):
        field: typing.Literal["bad_resource_state"] = "bad_resource_state"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "BadResourceState":
            return self._message.bad_resource_state
    
    class __OneOfClass_details_resource_not_found__(__OneOfClass_details__):
        field: typing.Literal["resource_not_found"] = "resource_not_found"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "ResourceNotFound":
            return self._message.resource_not_found
    
    class __OneOfClass_details_resource_already_exists__(__OneOfClass_details__):
        field: typing.Literal["resource_already_exists"] = "resource_already_exists"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "ResourceAlreadyExists":
            return self._message.resource_already_exists
    
    class __OneOfClass_details_out_of_range__(__OneOfClass_details__):
        field: typing.Literal["out_of_range"] = "out_of_range"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "OutOfRange":
            return self._message.out_of_range
    
    class __OneOfClass_details_permission_denied__(__OneOfClass_details__):
        field: typing.Literal["permission_denied"] = "permission_denied"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "PermissionDenied":
            return self._message.permission_denied
    
    class __OneOfClass_details_resource_conflict__(__OneOfClass_details__):
        field: typing.Literal["resource_conflict"] = "resource_conflict"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "ResourceConflict":
            return self._message.resource_conflict
    
    class __OneOfClass_details_operation_aborted__(__OneOfClass_details__):
        field: typing.Literal["operation_aborted"] = "operation_aborted"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "OperationAborted":
            return self._message.operation_aborted
    
    class __OneOfClass_details_too_many_requests__(__OneOfClass_details__):
        field: typing.Literal["too_many_requests"] = "too_many_requests"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "TooManyRequests":
            return self._message.too_many_requests
    
    class __OneOfClass_details_quota_failure__(__OneOfClass_details__):
        field: typing.Literal["quota_failure"] = "quota_failure"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "QuotaFailure":
            return self._message.quota_failure
    
    class __OneOfClass_details_internal_error__(__OneOfClass_details__):
        field: typing.Literal["internal_error"] = "internal_error"
        
        def __init__(self, msg: "ServiceError") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "InternalError":
            return self._message.internal_error
    
    @builtins.property
    def details(self) -> __OneOfClass_details_bad_request__|__OneOfClass_details_bad_resource_state__|__OneOfClass_details_resource_not_found__|__OneOfClass_details_resource_already_exists__|__OneOfClass_details_out_of_range__|__OneOfClass_details_permission_denied__|__OneOfClass_details_resource_conflict__|__OneOfClass_details_operation_aborted__|__OneOfClass_details_too_many_requests__|__OneOfClass_details_quota_failure__|__OneOfClass_details_internal_error__|None:
        """
        Additional message describing the error, if any.
        """
        
        field_name: str|None = super().which_field_in_oneof("details")
        match field_name:
            case "bad_request":
                return self.__OneOfClass_details_bad_request__(self)
            case "bad_resource_state":
                return self.__OneOfClass_details_bad_resource_state__(self)
            case "resource_not_found":
                return self.__OneOfClass_details_resource_not_found__(self)
            case "resource_already_exists":
                return self.__OneOfClass_details_resource_already_exists__(self)
            case "out_of_range":
                return self.__OneOfClass_details_out_of_range__(self)
            case "permission_denied":
                return self.__OneOfClass_details_permission_denied__(self)
            case "resource_conflict":
                return self.__OneOfClass_details_resource_conflict__(self)
            case "operation_aborted":
                return self.__OneOfClass_details_operation_aborted__(self)
            case "too_many_requests":
                return self.__OneOfClass_details_too_many_requests__(self)
            case "quota_failure":
                return self.__OneOfClass_details_quota_failure__(self)
            case "internal_error":
                return self.__OneOfClass_details_internal_error__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        service: "builtins.str|None|unset.UnsetType" = unset.Unset,
        code: "builtins.str|None|unset.UnsetType" = unset.Unset,
        bad_request: "BadRequest|common_errors_pb2.BadRequest|None|unset.UnsetType" = unset.Unset,
        bad_resource_state: "BadResourceState|common_errors_pb2.BadResourceState|None|unset.UnsetType" = unset.Unset,
        resource_not_found: "ResourceNotFound|common_errors_pb2.ResourceNotFound|None|unset.UnsetType" = unset.Unset,
        resource_already_exists: "ResourceAlreadyExists|common_errors_pb2.ResourceAlreadyExists|None|unset.UnsetType" = unset.Unset,
        out_of_range: "OutOfRange|common_errors_pb2.OutOfRange|None|unset.UnsetType" = unset.Unset,
        permission_denied: "PermissionDenied|common_errors_pb2.PermissionDenied|None|unset.UnsetType" = unset.Unset,
        resource_conflict: "ResourceConflict|common_errors_pb2.ResourceConflict|None|unset.UnsetType" = unset.Unset,
        operation_aborted: "OperationAborted|common_errors_pb2.OperationAborted|None|unset.UnsetType" = unset.Unset,
        too_many_requests: "TooManyRequests|common_errors_pb2.TooManyRequests|None|unset.UnsetType" = unset.Unset,
        quota_failure: "QuotaFailure|common_errors_pb2.QuotaFailure|None|unset.UnsetType" = unset.Unset,
        internal_error: "InternalError|common_errors_pb2.InternalError|None|unset.UnsetType" = unset.Unset,
        retry_type: "ServiceError.RetryType|error_pb2.ServiceError.RetryType|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(service, unset.UnsetType):
            self.service = service
        if not isinstance(code, unset.UnsetType):
            self.code = code
        if not isinstance(bad_request, unset.UnsetType):
            self.bad_request = bad_request
        if not isinstance(bad_resource_state, unset.UnsetType):
            self.bad_resource_state = bad_resource_state
        if not isinstance(resource_not_found, unset.UnsetType):
            self.resource_not_found = resource_not_found
        if not isinstance(resource_already_exists, unset.UnsetType):
            self.resource_already_exists = resource_already_exists
        if not isinstance(out_of_range, unset.UnsetType):
            self.out_of_range = out_of_range
        if not isinstance(permission_denied, unset.UnsetType):
            self.permission_denied = permission_denied
        if not isinstance(resource_conflict, unset.UnsetType):
            self.resource_conflict = resource_conflict
        if not isinstance(operation_aborted, unset.UnsetType):
            self.operation_aborted = operation_aborted
        if not isinstance(too_many_requests, unset.UnsetType):
            self.too_many_requests = too_many_requests
        if not isinstance(quota_failure, unset.UnsetType):
            self.quota_failure = quota_failure
        if not isinstance(internal_error, unset.UnsetType):
            self.internal_error = internal_error
        if not isinstance(retry_type, unset.UnsetType):
            self.retry_type = retry_type
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "service",
            "code",
            "bad_request",
            "bad_resource_state",
            "resource_not_found",
            "resource_already_exists",
            "out_of_range",
            "permission_denied",
            "resource_conflict",
            "operation_aborted",
            "too_many_requests",
            "quota_failure",
            "internal_error",
            "retry_type",
            "details",
            "RetryType",
        ]
    
    @builtins.property
    def service(self) -> "builtins.str":
        """
        ID of Service which the error originated in. E.g. "dns".
        """
        
        return super()._get_field("service", explicit_presence=False,
        )
    @service.setter
    def service(self, value: "builtins.str|None") -> None:
        return super()._set_field("service",value,explicit_presence=False,
        )
    
    @builtins.property
    def code(self) -> "builtins.str":
        """
        Detailed error code, service-specific. E.g. "DnsZoneNotEmpty".
        Name of the exception, without Exception suffix if not set
        Example: for PermissionDeniedException -> code == PermissionDenied
        """
        
        return super()._get_field("code", explicit_presence=False,
        )
    @code.setter
    def code(self, value: "builtins.str|None") -> None:
        return super()._set_field("code",value,explicit_presence=False,
        )
    
    @builtins.property
    def bad_request(self) -> "BadRequest|None":
        return super()._get_field("bad_request", explicit_presence=True,
        wrap=BadRequest,
        )
    @bad_request.setter
    def bad_request(self, value: "BadRequest|common_errors_pb2.BadRequest|None") -> None:
        return super()._set_field("bad_request",value,explicit_presence=True,
        )
    
    @builtins.property
    def bad_resource_state(self) -> "BadResourceState|None":
        return super()._get_field("bad_resource_state", explicit_presence=True,
        wrap=BadResourceState,
        )
    @bad_resource_state.setter
    def bad_resource_state(self, value: "BadResourceState|common_errors_pb2.BadResourceState|None") -> None:
        return super()._set_field("bad_resource_state",value,explicit_presence=True,
        )
    
    @builtins.property
    def resource_not_found(self) -> "ResourceNotFound|None":
        return super()._get_field("resource_not_found", explicit_presence=True,
        wrap=ResourceNotFound,
        )
    @resource_not_found.setter
    def resource_not_found(self, value: "ResourceNotFound|common_errors_pb2.ResourceNotFound|None") -> None:
        return super()._set_field("resource_not_found",value,explicit_presence=True,
        )
    
    @builtins.property
    def resource_already_exists(self) -> "ResourceAlreadyExists|None":
        return super()._get_field("resource_already_exists", explicit_presence=True,
        wrap=ResourceAlreadyExists,
        )
    @resource_already_exists.setter
    def resource_already_exists(self, value: "ResourceAlreadyExists|common_errors_pb2.ResourceAlreadyExists|None") -> None:
        return super()._set_field("resource_already_exists",value,explicit_presence=True,
        )
    
    @builtins.property
    def out_of_range(self) -> "OutOfRange|None":
        return super()._get_field("out_of_range", explicit_presence=True,
        wrap=OutOfRange,
        )
    @out_of_range.setter
    def out_of_range(self, value: "OutOfRange|common_errors_pb2.OutOfRange|None") -> None:
        return super()._set_field("out_of_range",value,explicit_presence=True,
        )
    
    @builtins.property
    def permission_denied(self) -> "PermissionDenied|None":
        return super()._get_field("permission_denied", explicit_presence=True,
        wrap=PermissionDenied,
        )
    @permission_denied.setter
    def permission_denied(self, value: "PermissionDenied|common_errors_pb2.PermissionDenied|None") -> None:
        return super()._set_field("permission_denied",value,explicit_presence=True,
        )
    
    @builtins.property
    def resource_conflict(self) -> "ResourceConflict|None":
        return super()._get_field("resource_conflict", explicit_presence=True,
        wrap=ResourceConflict,
        )
    @resource_conflict.setter
    def resource_conflict(self, value: "ResourceConflict|common_errors_pb2.ResourceConflict|None") -> None:
        return super()._set_field("resource_conflict",value,explicit_presence=True,
        )
    
    @builtins.property
    def operation_aborted(self) -> "OperationAborted|None":
        return super()._get_field("operation_aborted", explicit_presence=True,
        wrap=OperationAborted,
        )
    @operation_aborted.setter
    def operation_aborted(self, value: "OperationAborted|common_errors_pb2.OperationAborted|None") -> None:
        return super()._set_field("operation_aborted",value,explicit_presence=True,
        )
    
    @builtins.property
    def too_many_requests(self) -> "TooManyRequests|None":
        return super()._get_field("too_many_requests", explicit_presence=True,
        wrap=TooManyRequests,
        )
    @too_many_requests.setter
    def too_many_requests(self, value: "TooManyRequests|common_errors_pb2.TooManyRequests|None") -> None:
        return super()._set_field("too_many_requests",value,explicit_presence=True,
        )
    
    @builtins.property
    def quota_failure(self) -> "QuotaFailure|None":
        return super()._get_field("quota_failure", explicit_presence=True,
        wrap=QuotaFailure,
        )
    @quota_failure.setter
    def quota_failure(self, value: "QuotaFailure|common_errors_pb2.QuotaFailure|None") -> None:
        return super()._set_field("quota_failure",value,explicit_presence=True,
        )
    
    @builtins.property
    def internal_error(self) -> "InternalError|None":
        return super()._get_field("internal_error", explicit_presence=True,
        wrap=InternalError,
        )
    @internal_error.setter
    def internal_error(self, value: "InternalError|common_errors_pb2.InternalError|None") -> None:
        return super()._set_field("internal_error",value,explicit_presence=True,
        )
    
    @builtins.property
    def retry_type(self) -> "ServiceError.RetryType":
        """
        Retry type tells how to provide retry, e.g.: just a single call or the whole logic before it.
        """
        
        return super()._get_field("retry_type", explicit_presence=False,
        wrap=ServiceError.RetryType,
        )
    @retry_type.setter
    def retry_type(self, value: "ServiceError.RetryType|error_pb2.ServiceError.RetryType|None") -> None:
        return super()._set_field("retry_type",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "service":"service",
        "code":"code",
        "bad_request":"bad_request",
        "bad_resource_state":"bad_resource_state",
        "resource_not_found":"resource_not_found",
        "resource_already_exists":"resource_already_exists",
        "out_of_range":"out_of_range",
        "permission_denied":"permission_denied",
        "resource_conflict":"resource_conflict",
        "operation_aborted":"operation_aborted",
        "too_many_requests":"too_many_requests",
        "quota_failure":"quota_failure",
        "internal_error":"internal_error",
        "retry_type":"retry_type",
        "details":"details",
        "RetryType":"RetryType",
    }
    
__all__ = [
    #@ local import names here @#
    "BadRequest",
    "BadResourceState",
    "ResourceNotFound",
    "ResourceAlreadyExists",
    "ResourceConflict",
    "OperationAborted",
    "OutOfRange",
    "PermissionDenied",
    "InternalError",
    "TooManyRequests",
    "QuotaFailure",
    "ServiceError",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/applications/v1alpha1/k8s_release_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.applications.v1alpha1 import k8s_release_pb2 as nebius_dot_applications_dot_v1alpha1_dot_k8s__release__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6nebius/applications/v1alpha1/k8s_release_service.proto\x12\x1cnebius.applications.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a.nebius/applications/v1alpha1/k8s_release.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\".\n\x14GetK8sReleaseRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xb8\x01\n\x16ListK8sReleasesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\x12%\n\ncluster_id\x18\x05 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tclusterId\"\x9b\x01\n\x17\x43reateK8sReleaseRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12@\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.applications.v1alpha1.K8sReleaseSpecR\x04spec\"\x9b\x01\n\x17UpdateK8sReleaseRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12@\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.applications.v1alpha1.K8sReleaseSpecR\x04spec\"1\n\x17\x44\x65leteK8sReleaseRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x81\x01\n\x17ListK8sReleasesResponse\x12>\n\x05items\x18\x01 \x03(\x0b\x32(.nebius.applications.v1alpha1.K8sReleaseR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xa2\x04\n\x11K8sReleaseService\x12\x63\n\x03Get\x12\x32.nebius.applications.v1alpha1.GetK8sReleaseRequest\x1a(.nebius.applications.v1alpha1.K8sRelease\x12s\n\x04List\x12\x34.nebius.applications.v1alpha1.ListK8sReleasesRequest\x1a\x35.nebius.applications.v1alpha1.ListK8sReleasesResponse\x12\\\n\x06\x43reate\x12\x35.nebius.applications.v1alpha1.CreateK8sReleaseRequest\x1a\x1b.nebius.common.v1.Operation\x12\\\n\x06Update\x12\x35.nebius.applications.v1alpha1.UpdateK8sReleaseRequest\x1a\x1b.nebius.common.v1.Operation\x12\\\n\x06\x44\x65lete\x12\x35.nebius.applications.v1alpha1.DeleteK8sReleaseRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x19\xbaJ\x16\x64\x65ployment-manager.mktB{\n#ai.nebius.pub.applications.v1alpha1B\x16K8SReleaseServiceProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.applications.v1alpha1.k8s_release_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.applications.v1alpha1B\026K8SReleaseServiceProtoP\001Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1'
  _GETK8SRELEASEREQUEST.fields_by_name['id']._options = None
  _GETK8SRELEASEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTK8SRELEASESREQUEST.fields_by_name['parent_id']._options = None
  _LISTK8SRELEASESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTK8SRELEASESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTK8SRELEASESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEK8SRELEASEREQUEST.fields_by_name['id']._options = None
  _DELETEK8SRELEASEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _K8SRELEASESERVICE._options = None
  _K8SRELEASESERVICE._serialized_options = b'\272J\026deployment-manager.mkt'
  _globals['_GETK8SRELEASEREQUEST']._serialized_start=258
  _globals['_GETK8SRELEASEREQUEST']._serialized_end=304
  _globals['_LISTK8SRELEASESREQUEST']._serialized_start=307
  _globals['_LISTK8SRELEASESREQUEST']._serialized_end=491
  _globals['_CREATEK8SRELEASEREQUEST']._serialized_start=494
  _globals['_CREATEK8SRELEASEREQUEST']._serialized_end=649
  _globals['_UPDATEK8SRELEASEREQUEST']._serialized_start=652
  _globals['_UPDATEK8SRELEASEREQUEST']._serialized_end=807
  _globals['_DELETEK8SRELEASEREQUEST']._serialized_start=809
  _globals['_DELETEK8SRELEASEREQUEST']._serialized_end=858
  _globals['_LISTK8SRELEASESRESPONSE']._serialized_start=861
  _globals['_LISTK8SRELEASESRESPONSE']._serialized_end=990
  _globals['_K8SRELEASESERVICE']._serialized_start=993
  _globals['_K8SRELEASESERVICE']._serialized_end=1539
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/audit_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius.audit.v2 import authentication_pb2 as nebius_dot_audit_dot_v2_dot_authentication__pb2
from nebius.api.nebius.audit.v2 import authorization_pb2 as nebius_dot_audit_dot_v2_dot_authorization__pb2
from nebius.api.nebius.audit.v2 import region_pb2 as nebius_dot_audit_dot_v2_dot_region__pb2
from nebius.api.nebius.audit.v2 import request_pb2 as nebius_dot_audit_dot_v2_dot_request__pb2
from nebius.api.nebius.audit.v2 import resource_pb2 as nebius_dot_audit_dot_v2_dot_resource__pb2
from nebius.api.nebius.audit.v2 import response_pb2 as nebius_dot_audit_dot_v2_dot_response__pb2
from nebius.api.nebius.audit.v2 import service_pb2 as nebius_dot_audit_dot_v2_dot_service__pb2
from nebius.api.nebius.audit.v2 import status_pb2 as nebius_dot_audit_dot_v2_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/audit/v2/audit_event.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$nebius/audit/v2/authentication.proto\x1a#nebius/audit/v2/authorization.proto\x1a\x1cnebius/audit/v2/region.proto\x1a\x1dnebius/audit/v2/request.proto\x1a\x1enebius/audit/v2/resource.proto\x1a\x1enebius/audit/v2/response.proto\x1a\x1dnebius/audit/v2/service.proto\x1a\x1cnebius/audit/v2/status.proto\"\xf6\x05\n\nAuditEvent\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12\x1e\n\x06source\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06source\x12)\n\x0cspec_version\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0bspecVersion\x12\x1a\n\x04type\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04type\x12:\n\x07service\x18\x05 \x01(\x0b\x32\x18.nebius.audit.v2.ServiceB\x06\xbaH\x03\xc8\x01\x01R\x07service\x12\x1e\n\x06\x61\x63tion\x18\x06 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06\x61\x63tion\x12\x36\n\x04time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x04time\x12+\n\revent_version\x18\x08 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0c\x65ventVersion\x12G\n\x0e\x61uthentication\x18\t \x01(\x0b\x32\x1f.nebius.audit.v2.AuthenticationR\x0e\x61uthentication\x12\x44\n\rauthorization\x18\n \x01(\x0b\x32\x1e.nebius.audit.v2.AuthorizationR\rauthorization\x12\x35\n\x08resource\x18\x0b \x01(\x0b\x32\x19.nebius.audit.v2.ResourceR\x08resource\x12\x32\n\x07request\x18\x0c \x01(\x0b\x32\x18.nebius.audit.v2.RequestR\x07request\x12\x35\n\x08response\x18\r \x01(\x0b\x32\x19.nebius.audit.v2.ResponseR\x08response\x12\x37\n\x06status\x18\x10 \x01(\x0e\x32\x17.nebius.audit.v2.StatusB\x06\xbaH\x03\xc8\x01\x01R\x06status\x12>\n\x0eproject_region\x18\x11 \x01(\x0b\x32\x17.nebius.audit.v2.RegionR\rprojectRegionBZ\n\x16\x61i.nebius.pub.audit.v2B\x0f\x41uditEventProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.audit_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\017AuditEventProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _AUDITEVENT.fields_by_name['id']._options = None
  _AUDITEVENT.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['source']._options = None
  _AUDITEVENT.fields_by_name['source']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['spec_version']._options = None
  _AUDITEVENT.fields_by_name['spec_version']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['type']._options = None
  _AUDITEVENT.fields_by_name['type']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['service']._options = None
  _AUDITEVENT.fields_by_name['service']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['action']._options = None
  _AUDITEVENT.fields_by_name['action']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['time']._options = None
  _AUDITEVENT.fields_by_name['time']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['event_version']._options = None
  _AUDITEVENT.fields_by_name['event_version']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['status']._options = None
  _AUDITEVENT.fields_by_name['status']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AUDITEVENT']._serialized_start=378
  _globals['_AUDITEVENT']._serialized_end=1136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/scope.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnebius/vpc/v1alpha1/scope.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xb5\x01\n\x05Scope\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.nebius.vpc.v1alpha1.ScopeSpecR\x04spec\x12\x38\n\x06status\x18\x03 \x01(\x0b\x32 .nebius.vpc.v1alpha1.ScopeStatusR\x06status\"\x89\x01\n\tScopeSpec\x12?\n\x04type\x18\x01 \x01(\x0e\x32#.nebius.vpc.v1alpha1.ScopeSpec.TypeB\x06\xbaH\x03\xc8\x01\x01R\x04type\";\n\x04Type\x12\x1a\n\x16SCOPE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\x92\x01\n\x0bScopeStatus\x12<\n\x05state\x18\x01 \x01(\x0e\x32&.nebius.vpc.v1alpha1.ScopeStatus.StateR\x05state\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42]\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\nScopeProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.scope_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\nScopeProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _SCOPESPEC.fields_by_name['type']._options = None
  _SCOPESPEC.fields_by_name['type']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SCOPE']._serialized_start=119
  _globals['_SCOPE']._serialized_end=300
  _globals['_SCOPESPEC']._serialized_start=303
  _globals['_SCOPESPEC']._serialized_end=440
  _globals['_SCOPESPEC_TYPE']._serialized_start=381
  _globals['_SCOPESPEC_TYPE']._serialized_end=440
  _globals['_SCOPESTATUS']._serialized_start=443
  _globals['_SCOPESTATUS']._serialized_end=589
  _globals['_SCOPESTATUS_STATE']._serialized_start=520
  _globals['_SCOPESTATUS_STATE']._serialized_end=589
# @@protoc_insertion_point(module_scope)



from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Image(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: ImageSpec
    status: ImageStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[ImageSpec, _Mapping]] = ..., status: _Optional[_Union[ImageStatus, _Mapping]] = ...) -> None: ...

class ImageSpec(_message.Message):
    __slots__ = ["description", "image_family", "version", "cpu_architecture"]
    class CPUArchitecture(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNSPECIFIED: _ClassVar[ImageSpec.CPUArchitecture]
        AMD64: _ClassVar[ImageSpec.CPUArchitecture]
        ARM64: _ClassVar[ImageSpec.CPUArchitecture]
    UNSPECIFIED: ImageSpec.CPUArchitecture
    AMD64: ImageSpec.CPUArchitecture
    ARM64: ImageSpec.CPUArchitecture
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FAMILY_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CPU_ARCHITECTURE_FIELD_NUMBER: _ClassVar[int]
    description: str
    image_family: str
    version: str
    cpu_architecture: ImageSpec.CPUArchitecture
    def __init__(self, description: _Optional[str] = ..., image_family: _Optional[str] = ..., version: _Optional[str] = ..., cpu_architecture: _Optional[_Union[ImageSpec.CPUArchitecture, str]] = ...) -> None: ...

class ImageStatus(_message.Message):
    __slots__ = ["state", "state_description", "storage_size_bytes", "min_disk_size_bytes", "reconciling"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNSPECIFIED: _ClassVar[ImageStatus.State]
        CREATING: _ClassVar[ImageStatus.State]
        READY: _ClassVar[ImageStatus.State]
        UPDATING: _ClassVar[ImageStatus.State]
        DELETING: _ClassVar[ImageStatus.State]
        ERROR: _ClassVar[ImageStatus.State]
    UNSPECIFIED: ImageStatus.State
    CREATING: ImageStatus.State
    READY: ImageStatus.State
    UPDATING: ImageStatus.State
    DELETING: ImageStatus.State
    ERROR: ImageStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    STORAGE_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    MIN_DISK_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    RECONCILING_FIELD_NUMBER: _ClassVar[int]
    state: ImageStatus.State
    state_description: str
    storage_size_bytes: int
    min_disk_size_bytes: int
    reconciling: bool
    def __init__(self, state: _Optional[_Union[ImageStatus.State, str]] = ..., state_description: _Optional[str] = ..., storage_size_bytes: _Optional[int] = ..., min_disk_size_bytes: _Optional[int] = ..., reconciling: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/subject.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnebius/audit/v2/subject.proto\x12\x0fnebius.audit.v2\"{\n\x07Subject\x12.\n\x12service_account_id\x18\n \x01(\tH\x00R\x10serviceAccountId\x12&\n\x0etenant_user_id\x18\x0b \x01(\tH\x00R\x0ctenantUserId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04nameB\x04\n\x02idBW\n\x16\x61i.nebius.pub.audit.v2B\x0cSubjectProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.subject_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\014SubjectProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _globals['_SUBJECT']._serialized_start=50
  _globals['_SUBJECT']._serialized_end=173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/network_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.vpc.v1alpha1 import network_pb2 as nebius_dot_vpc_dot_v1alpha1_dot_network__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/vpc/v1alpha1/network_service.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a!nebius/vpc/v1alpha1/network.proto\"+\n\x11GetNetworkRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"Z\n\x17GetNetworkByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x8e\x01\n\x13ListNetworksRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"r\n\x14ListNetworksResponse\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32\x1c.nebius.vpc.v1alpha1.NetworkR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x9b\x02\n\x0eNetworkService\x12K\n\x03Get\x12&.nebius.vpc.v1alpha1.GetNetworkRequest\x1a\x1c.nebius.vpc.v1alpha1.Network\x12W\n\tGetByName\x12,.nebius.vpc.v1alpha1.GetNetworkByNameRequest\x1a\x1c.nebius.vpc.v1alpha1.Network\x12[\n\x04List\x12(.nebius.vpc.v1alpha1.ListNetworksRequest\x1a).nebius.vpc.v1alpha1.ListNetworksResponse\x1a\x06\xbaJ\x03vpcBf\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\x13NetworkServiceProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.network_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\023NetworkServiceProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _GETNETWORKREQUEST.fields_by_name['id']._options = None
  _GETNETWORKREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETNETWORKBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETNETWORKBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETNETWORKBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETNETWORKBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTNETWORKSREQUEST.fields_by_name['parent_id']._options = None
  _LISTNETWORKSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _NETWORKSERVICE._options = None
  _NETWORKSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETNETWORKREQUEST']._serialized_start=156
  _globals['_GETNETWORKREQUEST']._serialized_end=199
  _globals['_GETNETWORKBYNAMEREQUEST']._serialized_start=201
  _globals['_GETNETWORKBYNAMEREQUEST']._serialized_end=291
  _globals['_LISTNETWORKSREQUEST']._serialized_start=294
  _globals['_LISTNETWORKSREQUEST']._serialized_end=436
  _globals['_LISTNETWORKSRESPONSE']._serialized_start=438
  _globals['_LISTNETWORKSRESPONSE']._serialized_end=552
  _globals['_NETWORKSERVICE']._serialized_start=555
  _globals['_NETWORKSERVICE']._serialized_end=838
# @@protoc_insertion_point(module_scope)
